@@ -1,15 +1,5 @@
 module HROOT.Graf.TArc
-  (
-    TArc(..)
-  , ITArc
-  , upcastTArc
-  , downcastTArc
-  , newTArc
- 
-  ) where
-
+       (TArc(..), ITArc, upcastTArc, downcastTArc, newTArc) where
 import HROOT.Graf.TArc.RawType
 import HROOT.Graf.TArc.Interface
 import HROOT.Graf.TArc.Implementation
-
-
