@@ -1,15 +1,6 @@
 module HROOT.Graf.TArrow
-  (
-    TArrow(..)
-  , ITArrow
-  , upcastTArrow
-  , downcastTArrow
-  , newTArrow
- 
-  ) where
-
+       (TArrow(..), ITArrow, upcastTArrow, downcastTArrow, newTArrow)
+       where
 import HROOT.Graf.TArrow.RawType
 import HROOT.Graf.TArrow.Interface
 import HROOT.Graf.TArrow.Implementation
-
-
