@@ -1,15 +1,6 @@
 module HROOT.Graf.TAttImage
-  (
-    TAttImage(..)
-  , ITAttImage
-  , upcastTAttImage
-  , downcastTAttImage
-
- 
-  ) where
-
+       (TAttImage(..), ITAttImage, upcastTAttImage, downcastTAttImage)
+       where
 import HROOT.Graf.TAttImage.RawType
 import HROOT.Graf.TAttImage.Interface
 import HROOT.Graf.TAttImage.Implementation
-
-
