@@ -1,15 +1,5 @@
 module HROOT.Graf.TBRIK
-  (
-    TBRIK(..)
-  , ITBRIK
-  , upcastTBRIK
-  , downcastTBRIK
-  , newTBRIK
- 
-  ) where
-
+       (TBRIK(..), ITBRIK, upcastTBRIK, downcastTBRIK, newTBRIK) where
 import HROOT.Graf.TBRIK.RawType
 import HROOT.Graf.TBRIK.Interface
 import HROOT.Graf.TBRIK.Implementation
-
-
