@@ -1,15 +1,7 @@
 module HROOT.Graf.TCanvas
-  (
-    TCanvas(..)
-  , ITCanvas
-  , upcastTCanvas
-  , downcastTCanvas
-  , newTCanvas
- 
-  ) where
-
+       (TCanvas(..), ITCanvas(..), upcastTCanvas, downcastTCanvas,
+        newTCanvas)
+       where
 import HROOT.Graf.TCanvas.RawType
 import HROOT.Graf.TCanvas.Interface
 import HROOT.Graf.TCanvas.Implementation
-
-
