@@ -1,15 +1,6 @@
 module HROOT.Graf.TCrown
-  (
-    TCrown(..)
-  , ITCrown
-  , upcastTCrown
-  , downcastTCrown
-  , newTCrown
- 
-  ) where
-
+       (TCrown(..), ITCrown, upcastTCrown, downcastTCrown, newTCrown)
+       where
 import HROOT.Graf.TCrown.RawType
 import HROOT.Graf.TCrown.Interface
 import HROOT.Graf.TCrown.Implementation
-
-
