@@ -1,15 +1,5 @@
 module HROOT.Graf.TCutG
-  (
-    TCutG(..)
-  , ITCutG
-  , upcastTCutG
-  , downcastTCutG
-  , newTCutG
- 
-  ) where
-
+       (TCutG(..), ITCutG, upcastTCutG, downcastTCutG, newTCutG) where
 import HROOT.Graf.TCutG.RawType
 import HROOT.Graf.TCutG.Interface
 import HROOT.Graf.TCutG.Implementation
-
-
