@@ -1,15 +1,7 @@
 module HROOT.Graf.TEllipse
-  (
-    TEllipse(..)
-  , ITEllipse
-  , upcastTEllipse
-  , downcastTEllipse
-  , newTEllipse
- 
-  ) where
-
+       (TEllipse(..), ITEllipse, upcastTEllipse, downcastTEllipse,
+        newTEllipse)
+       where
 import HROOT.Graf.TEllipse.RawType
 import HROOT.Graf.TEllipse.Interface
 import HROOT.Graf.TEllipse.Implementation
-
-
