@@ -1,15 +1,6 @@
 module HROOT.Graf.TGaxis
-  (
-    TGaxis(..)
-  , ITGaxis
-  , upcastTGaxis
-  , downcastTGaxis
-  , newTGaxis
- 
-  ) where
-
+       (TGaxis(..), ITGaxis, upcastTGaxis, downcastTGaxis, newTGaxis)
+       where
 import HROOT.Graf.TGaxis.RawType
 import HROOT.Graf.TGaxis.Interface
 import HROOT.Graf.TGaxis.Implementation
-
-
