@@ -1,15 +1,7 @@
 module HROOT.Graf.TGraphPolar
-  (
-    TGraphPolar(..)
-  , ITGraphPolar
-  , upcastTGraphPolar
-  , downcastTGraphPolar
-  , newTGraphPolar
- 
-  ) where
-
+       (TGraphPolar(..), ITGraphPolar, upcastTGraphPolar,
+        downcastTGraphPolar, newTGraphPolar)
+       where
 import HROOT.Graf.TGraphPolar.RawType
 import HROOT.Graf.TGraphPolar.Interface
 import HROOT.Graf.TGraphPolar.Implementation
-
-
