@@ -1,15 +1,7 @@
 module HROOT.Graf.TGraphQQ
-  (
-    TGraphQQ(..)
-  , ITGraphQQ
-  , upcastTGraphQQ
-  , downcastTGraphQQ
-  , newTGraphQQ
- 
-  ) where
-
+       (TGraphQQ(..), ITGraphQQ, upcastTGraphQQ, downcastTGraphQQ,
+        newTGraphQQ)
+       where
 import HROOT.Graf.TGraphQQ.RawType
 import HROOT.Graf.TGraphQQ.Interface
 import HROOT.Graf.TGraphQQ.Implementation
-
-
