@@ -1,15 +1,5 @@
 module HROOT.Graf.TPCON
-  (
-    TPCON(..)
-  , ITPCON
-  , upcastTPCON
-  , downcastTPCON
-  , newTPCON
- 
-  ) where
-
+       (TPCON(..), ITPCON, upcastTPCON, downcastTPCON, newTPCON) where
 import HROOT.Graf.TPCON.RawType
 import HROOT.Graf.TPCON.Interface
 import HROOT.Graf.TPCON.Implementation
-
-
