@@ -1,15 +1,5 @@
 module HROOT.Graf.TPad
-  (
-    TPad(..)
-  , ITPad
-  , upcastTPad
-  , downcastTPad
-
- 
-  ) where
-
+       (TPad(..), ITPad(..), upcastTPad, downcastTPad, newTPad) where
 import HROOT.Graf.TPad.RawType
 import HROOT.Graf.TPad.Interface
 import HROOT.Graf.TPad.Implementation
-
-
