@@ -1,15 +1,5 @@
 module HROOT.Graf.TSPHE
-  (
-    TSPHE(..)
-  , ITSPHE
-  , upcastTSPHE
-  , downcastTSPHE
-  , newTSPHE
- 
-  ) where
-
+       (TSPHE(..), ITSPHE, upcastTSPHE, downcastTSPHE, newTSPHE) where
 import HROOT.Graf.TSPHE.RawType
 import HROOT.Graf.TSPHE.Interface
 import HROOT.Graf.TSPHE.Implementation
-
-
