@@ -1,15 +1,6 @@
 module HROOT.Graf.TShape
-  (
-    TShape(..)
-  , ITShape
-  , upcastTShape
-  , downcastTShape
-  , newTShape
- 
-  ) where
-
+       (TShape(..), ITShape, upcastTShape, downcastTShape, newTShape)
+       where
 import HROOT.Graf.TShape.RawType
 import HROOT.Graf.TShape.Interface
 import HROOT.Graf.TShape.Implementation
-
-
