@@ -1,15 +1,5 @@
 module HROOT.Graf.TTUBE
-  (
-    TTUBE(..)
-  , ITTUBE
-  , upcastTTUBE
-  , downcastTTUBE
-  , newTTUBE
- 
-  ) where
-
+       (TTUBE(..), ITTUBE, upcastTTUBE, downcastTTUBE, newTTUBE) where
 import HROOT.Graf.TTUBE.RawType
 import HROOT.Graf.TTUBE.Interface
 import HROOT.Graf.TTUBE.Implementation
-
-
